[![](https://github.com/archspec/archspec-json/workflows/JSON%20Validation/badge.svg)](https://github.com/archspec/archspec-json/actions)

# Archspec-json

The [archspec-json](https://github.com/archspec/archspec-json) repository is part of the
[Archspec](https://github.com/archspec) project. It contains data on various architectural
aspects of a platform stored in JSON format and is meant to be used as a base to develop
language specific APIs.

Currently the repository contains the following JSON files:
```console
.
├── COPYRIGHT
└── cpu
    ├── microarchitectures.json         # Contains information on CPU microarchitectures
    └── microarchitectures_schema.json  # Schema for the file above
```